
from pathlib import Path

from rinoh.font import Typeface
from rinoh.font.opentype import OpenTypeFont


__all__ = ['typeface']


DIR = Path(__file__).parent
FONTS = [OpenTypeFont(ttf) for ttf in [*DIR.glob('*.TTF'), *DIR.glob('*.ttf')]]

typeface = Typeface('Comic Sans MS', *FONTS)



from rinoh_mscorefontinstaller import setup


setup(
    name='Comic Sans MS',
    version='0.1.0',
    archive='comic32.exe',
    sha256sum='9c6df3feefde26d4e41d4a4fe5db2a89f9123a772594d7f59afd062625cd204e',
    setup_file=__file__
)
